@@ -14,21 +14,18 @@ PSM.template <- function(Linear=FALSE,dimX=2,dimY=3,dimU=4,dimEta=5,file="") {
     str <- paste(str,"       )",sep="\n")
     str <- paste(str,"}",sep="\n")
   } else {
-    str <- paste(str,"MyModel$Functions <- ",sep="\n")
-    str <- paste(str,"  list(",sep="\n")
-    str <- paste(str,"       f = function(x,u,time,phi) {",sep="\n")
-    str <- paste(str,"\n         matrix(c(  ), nrow=",dimX,", ncol=1)",sep="")  
-    str <- paste(str,"       },",sep="\n")
-    str <- paste(str,"       df = function(x,u,time,phi) {",sep="\n")
-    str <- paste(str,"\n         matrix(c(  ), nrow=",dimX,", ncol=",dimX,")",sep="")  
-    str <- paste(str,"       },",sep="\n")
-    str <- paste(str,"       g = function(x,u,time,phi) {",sep="\n")
-    str <- paste(str,"\n         matrix(c(  ), nrow=",dimY,", ncol=1)",sep="")  
-    str <- paste(str,"       },",sep="\n")
-    str <- paste(str,"       dg = function(x,u,time,phi) {",sep="\n")
-    str <- paste(str,"\n         matrix(c(  ), nrow=",dimY,", ncol=",dimX,")",sep="")  
-    str <- paste(str,"       }",sep="\n")
-    str <- paste(str,"       )",sep="\n")
+    str <- paste(str,"MyModel$Functions$f = function(x,u,time,phi) {",sep="\n")
+    str <- paste(str,"\n  matrix(c(  ), nrow=",dimX,", ncol=1)",sep="")  
+    str <- paste(str,"}",sep="\n")
+    str <- paste(str,"MyModel$Functions$df = function(x,u,time,phi) {",sep="\n")
+    str <- paste(str,"\n  matrix(c(  ), nrow=",dimX,", ncol=",dimX,")",sep="")  
+    str <- paste(str,"}",sep="\n")
+    str <- paste(str,"MyModel$Functions$g = function(x,u,time,phi) {",sep="\n")
+    str <- paste(str,"\n  matrix(c(  ), nrow=",dimY,", ncol=1)",sep="")  
+    str <- paste(str,"}",sep="\n")
+    str <- paste(str,"MyModel$Functions$dg = function(x,u,time,phi) {",sep="\n")
+    str <- paste(str,"\n  matrix(c(  ), nrow=",dimY,", ncol=",dimX,")",sep="")  
+    str <- paste(str,"}",sep="\n")
   }
 
   str <- paste(str,"MyModel$h = function(eta,theta,covar) {",sep="\n")
